Testing is done using pytest. After installing pytest via ``pip``, a typical run of the SQLAlchemy test suite
can be performed by running::

(venv) C:\Users\Gord\git\sqlalchemy-sybase>pytest

or, for more verbose output::

(venv) C:\Users\Gord\git\sqlalchemy-sybase>pytest -v
